#!/bin/bash

FFMPEG_SRC_ROOTPATH=./sources
FFMPEG_TARGET_OS=ios
FFMPEG_BIN_OUTPUT=../bin/$FFMPEG_TARGET_OS
FFMPEG_IOS_SDK_VERSION=4.2
FFMPEG_IOS_SDK_ROOTPATH=/Developer/Platforms/iPhoneOS.platform/Developer/SDKs/iPhoneOS$FFMPEG_IOS_SDK_VERSION.sdk
FFMPEG_IOS_SDK_GCC_PATH=/Developer/Platforms/iPhoneOS.platform/Developer/usr/bin/gcc

FFMPEG_IOS_CONFIGURE_PARAMETERS="--disable-debug --disable-pthreads --disable-network --disable-zlib --disable-mpegaudio-hp --disable-doc --disable-ffprobe --disable-ffmpeg --disable-ffserver \
--disable-ffplay --disable-encoders --disable-decoders --disable-devices --disable-muxers --disable-demuxers --disable-parsers \
--disable-protocols --disable-bsfs --disable-filters --disable-mmx \
--enable-decoder=cook --enable-decoder=mp3 --enable-decoder=mp3adu --enable-decoder=mp3on4 --enable-decoder=ra_144 \
--enable-decoder=ra_288 --enable-decoder=wmav1 --enable-decoder=wmav2 --enable-decoder=wmapro --enable-decoder=wmavoice \
--enable-decoder=aac --enable-decoder=aac_latm --enable-decoder=mpeg4 --enable-decoder=svq3 --enable-decoder=vorbis \
--enable-demuxer=asf --enable-demuxer=m4v --enable-demuxer=aac --enable-demuxer=mov --enable-demuxer=mp3 --enable-demuxer=rm --enable-demuxer=wav --enable-demuxer=ogg \
--enable-parser=aac --enable-parser=aac_latm --enable-parser=mpegaudio --enable-parser=h264 \
--enable-bsf=aac_adtstoasc \
--enable-stripping --enable-optimizations"

case "$1" in
armv6)
FFMPEG_IOS_TARGET_ARCH=armv6
FFMPEG_IOS_TARGET_CPU=arm1176jzf-s
FFMPEG_IOS_TARGET_DEVICES="Old generations iPhone/iPod 2G & 3G"
FFMPEG_IOS_CONFIGURE_PARAMETERS+=" --enable-cross-compile"
FFMPEG_IOS_ARCH_OPTIMIZATIONS=arm
;;
armv7)
FFMPEG_IOS_TARGET_ARCH=armv7
FFMPEG_IOS_TARGET_CPU=cortex-a8
FFMPEG_IOS_CONFIGURE_PARAMETERS+=" --enable-pic --enable-cross-compile"
FFMPEG_IOS_TARGET_DEVICES="iPhone/iPod 3GS & 4G, iPad"
FFMPEG_IOS_ARCH_OPTIMIZATIONS=arm
;;
*)
echo "ERROR: Unknown target platform. Please specify a valid configuration target."
echo "--> armv6 : Old generations iPhone/iPod 2G & 3G"
echo "--> armv7 : iPhone/iPod 3GS & 4 & 4S, iPad 1 & 2"
exit 
;;
esac

echo "Configuring FFmpeg for $FFMPEG_TARGET_OS with the following target parameters:"
echo "-->  ARCH=" $FFMPEG_IOS_TARGET_ARCH
echo "-->  CPU=" $FFMPEG_IOS_TARGET_CPU
echo "-->  DEVICES=" $FFMPEG_IOS_TARGET_DEVICES

echo "\nPlease wait..."

cd $FFMPEG_SRC_ROOTPATH

./configure --arch=$FFMPEG_IOS_ARCH_OPTIMIZATIONS --target-os=darwin --cpu=$FFMPEG_IOS_TARGET_CPU --cc="${FFMPEG_IOS_SDK_GCC_PATH} -arch ${FFMPEG_IOS_TARGET_ARCH}" --sysroot=$FFMPEG_IOS_SDK_ROOTPATH \
--enable-static --disable-shared --prefix=$FFMPEG_BIN_OUTPUT/$FFMPEG_IOS_TARGET_ARCH $FFMPEG_IOS_CONFIGURE_PARAMETERS

cp config.h config-${FFMPEG_TARGET_OS}_$FFMPEG_IOS_TARGET_ARCH.h

